@@ -1469,9 +1469,9 @@ void MoveUp(void)
 	else {
 		MagY = MagY + sagcad_system.ScrollPitch;
 	}
-	window_set();
+	SetMag(Mag);
 	/* --- <  > --- */
-	Redraw();
+//	Redraw();
 }
 
 
@@ -1487,9 +1487,9 @@ void MoveDown(void)
 	else {
 		MagY = MagY - sagcad_system.ScrollPitch;
 	}
-	window_set();
+	SetMag(Mag);
 	/* --- <  > --- */
-	Redraw();
+//	Redraw();
 }
 
 
@@ -1505,9 +1505,9 @@ void MoveRight(void)
 	else {
 		MagX = MagX + sagcad_system.ScrollPitch;
 	}
-	window_set();
+	SetMag(Mag);
 	/* --- <  > --- */
-	Redraw();
+//	Redraw();
 }
 
 
@@ -1523,9 +1523,9 @@ void MoveLeft(void)
 	else {
 		MagX = MagX - sagcad_system.ScrollPitch;
 	}
-	window_set();
+	SetMag(Mag);
 	/* --- <  > --- */
-	Redraw();
+//	Redraw();
 }
 
 
