@@ -267,7 +267,7 @@ int set_line_width(FILE *stream, double width)
 {
 	char str[256];
 
-	sprintf(str, "%f setlinewidth\n", width);
+	sprintf(str, "closepath\nstroke\nnewpath\n%f setlinewidth\n", width);
 	fputs(str, stream );
 	return 1;
 }
